*ATTENTION:
*change PC_FOLDER to the path where folder "chapter 3" is located on your computer
*example provided below
* pc folder
local PC_FOLDER "/Users/zhangjiwei/Desktop/UCLA/Boustan/Summer/Replication files/chapter 3"

cd "`PC_FOLDER'/figure_3.2/creating_4070merge_educ_dta"

set more off
clear
set mem 200m
use rawdata_borjas/platt001.dta

/* The sample is restricted to men aged 18-64 who do not reside in group quarters, report being in the civilian labor force, 
and report an occupation. Also, drop anyone who works as a farm manager or farm laborer. Also, drop those whose birthplace is 
unknown (only .01% of sample)*/
count
keep if sex==1
keep if age>=18 & age<=64
drop if gq==3 | gq==4
drop if empstatd>=31 & empstatd<=34
drop if empstatd>=13 & empstatd<=15
drop if occ1950==999 | occ1950==997
drop if occ1950>=100 & occ1950<=199
drop if occ1950>=800 & occ1950<=899
drop if bplg==99 | bplg>=997
count

** REGION 
/* Focus is on the North and West, the migrant-receiving areas. North includes DC, Maryland and Delaware. Otherwise, 
North = NE and Midwest census regions and West = Western Census region. Start with whole country*/
/* Two types of region variables. Region = N,W,S and Region01 has distinctions within the non-S*/
gen region01=region
replace region01=12 if region01>=31 & region01<=33
/* North, West, South*/
replace region=1 if region>=11 & region<=22
replace region=1 if statefip==10 | statefip==11 | statefip==24
replace region=2 if region>=31 & region<=33
replace region=3 if region>=41 & region<=43
label define reglbl 1 north 2 south 3 west  
label values region reglbl
/*Region categories*/
gen noreast=(region01==11)
gen midatl=(region01==12)
gen midwest1=(region01==21)
gen midwest2=(region01==22)
gen mountain=(region01==41)
gen pacific=(region01==42)

** RACE
/* Focus is on black migrants from the South. Division between black and non-black, rather than black and 
white. Alternatively, can drop other races (American Indian, Asian). But, need them for the counts*/
gen byte black=(raceg==2)
lab var black "=1 if black"
*** MIGRATION STATUS - MOVER/BORN IN SOUTH
/* Migration is a lifetime category. As in the immigration literature, immigrants are all who were "born 
abroad; all other persons are classified as natives." (Borjas).*/
#delimit ;
gen byte bornsouth=(bplg==1 | bplg==5 | bplg==12 | bplg==13 | bplg==21 | bplg==22 | bplg==28 | bplg==37 | 
bplg==40 | bplg==45 | bplg==47 | bplg==48 | bplg==51);
#delimit cr
gen byte bornnorth=(bornsouth==0 & bplg<99)
gen byte migsouth=(bornsouth==1 & region!=2)
gen byte mignorth=(bornnorth==1 & region==2)
label var bornsouth "=1 if born in south"
label var migsouth "=1 if born in south, now in N or W"
label var bornnorth "=1 if born in north"
label var mignorth "=1 if born in north, now in S"

** EDUCATION/EXPERIENCE GROUPS
/* Borjas divides the population into 4 education groups (high school dropout, hs graduate, some college and college graduate) 
and into 8 experience groups (in 5 year increments). However, the black population migrating from the South had very low 
levels of education --in 1940, more than 90% had below a HS graduation. In this case, divide by 5 education groups, but these 
four are: 0-5 yrs; 6-7 years; 8-10 yrs; 11-12 yrs; 13+ yrs */
** EDUCATION
gen higrade=0 if higradeg==1
replace higrade=(higradeg-3) if higrade!=0
gen edcat=1 if higrade>=0 & higrade<=5
replace edcat=2 if higrade>=6 & higrade<=9
replace edcat=3 if higrade>=10 & higrade<=11
replace edcat=4 if higrade>=12 & higrade<=12
replace edcat=5 if higrade>=13 & higrade!=.
/* Robust
gen edcat=1 if higrade>=0 & higrade<=6
replace edcat=2 if higrade>=7 & higrade<=8
replace edcat=3 if higrade>=9 & higrade<=10
replace edcat=4 if higrade>=11 & higrade<=12
replace edcat=5 if higrade>=13 & higrade!=.
*/
**EXPERIENCE
/* I do not use fixed assumptions about when people enter the labor market. Instead, I assume that all enter in the year 
after they leave school with the exception of those with the least amount of education*/
gen exper=(age-higrade-6)
replace exper=(age-12) if higrade<=5
label var exper "age - assumed age of entry"
/* Note: Restrict sample to those with 1-40 years of experience. This means, practically, that I drop all 
ages below the assumed age of first entry (e.g., for college grads, drop observations for ages less than 
23)*/
drop if exper<=0
drop if exper>=41
gen expcat=1 if exper>=1 & exper<=5
replace expcat=2 if exper>=6 & exper<=10
replace expcat=3 if exper>=11 & exper<=15
replace expcat=4 if exper>=16 & exper<=20
replace expcat=5 if exper>=21 & exper<=25
replace expcat=6 if exper>=26 & exper<=30
replace expcat=7 if exper>=31 & exper<=35
replace expcat=8 if exper>=36 & exper<=40
*replace expcat=9 if exper>=41 & exper<=45
*replace expcat=10 if exper>=46 & exper<=50
label var expcat "experience categories"
label define explbl 1 1to5 2 6to10 3 11to15 4 16to20 5 21to25 6 26to30 7 31to35 8 36to40
lab values expcat explbl

/* Two functions for the Southern data:
A. For reverse migration: 
(1) Count number of men by group who were born in North and now live in the South. 
(2) Count number of men by group who were born in the North
--> reverse migration (# born in N and now in S/# born in N) 
B. For instrument:
Count number in each group that were born in the South, regardless of where they currently live
Then, can drop southern observations altogether, and continue with the Northern sample. 
The "born in the South" instrument should be supplemented with a standard age-migration profile.
*/
sort age
merge age using migration_by_age.dta
tab _merge
keep if _merge==3
drop _merge
gen temp=(bornnorth==1 & black==0)
gen temp01=(mignorth==1 & black==0)
gen temp02=(bornnorth==1 & black==1)
gen temp03=(mignorth==1 & black==1)
gen temp04=(bornsouth==1 & black==0)
gen temp05=(bornsouth==1 & black==1)
gen temp04a=temp04*shmigrate
gen temp05a=temp05*shmigrate
sort edcat expcat
quietly by edcat expcat: egen countwnor=sum(temp) 
quietly by edcat expcat: egen countwnormi=sum(temp01) 
quietly by edcat expcat: egen countbnor=sum(temp02) 
quietly by edcat expcat: egen countbnormi=sum(temp03) 
by edcat expcat: egen countwsouth=sum(temp04)
by edcat expcat: egen countbsouth=sum(temp05)
by edcat expcat: egen countwsouth_a=sum(temp04a)
by edcat expcat: egen countbsouth_a=sum(temp05a)
drop temp*
gen perwnins=(countwnormi/countwnor)
gen perbnins=(countbnormi/countbnor)
drop countwnormi countwnor countbnormi countbnor
label var countwsouth "# whites born in south, by group"
label var countbsouth "# blacks born in south, by group"
label var perwnins "% of whites born in N now in S, by group"
label var perbnins "% of blacks born in N now in S, by group"
gen temp01=(black==1 & migsouth==1)
gen temp02=(black==0 & migsouth==1)
quietly by edcat expcat: egen countbmi=sum(temp01) 
quietly by edcat expcat: egen countwmi=sum(temp02) 
label var countbmi "# blacks born in S, live in N, by group"
label var countwmi "# whites born in S, live in N, by group"
save 1940b02_educ.dta, replace

/* Make southern file*/
keep if region==2
*save 1940_south.dta, replace

/* Now, drop everyone who lives in the South whether born there or migrated there from the North. The rest of the analysis is 
based on northerners alone*/
clear 
use 1940b02_educ.dta
drop if region==2

/* For Table 1*/
summ migsouth temp01 temp02
summ migsouth temp01 temp02 if edcat==1
summ migsouth temp01 temp02 if edcat==3
summ migsouth temp01 temp02 if edcat==5

**COUNTS BY GROUP (ED X EXP)
/* Sort into the 40 education x experience categories. Count total workforce, and then black 
workers, black migrant workers, and all migrant workers*/
sort edcat expcat
drop temp*
gen temp=(black==1)
gen temp01=1
quietly by edcat expcat: egen count=sum(temp01)
quietly by edcat expcat: egen countb=sum(temp) 
label var count "total # in N LF, by group"
label var countb "# blacks in N LF, by group" 

** PERCENTAGE MIGRANT
gen perwmi=(countwmi/count)
gen perbmi=(countbmi/count)
label var perwmi "% of N LF white southern migrant, by group"
label var perbmi "% of N LF black southern migrant, by group"

/* In some cases, for robustness, want to include women in the counts though not in the wage regressions*/
*keep if sex==1
/* Try dropping the foreign-born or the native-born*/
*drop if bplg>56 & black==0
*drop if bplg<57 & black==0

/* Dependent Variables*/
/* Further restrict the sample to those who are not self-employed and not enrolled in school. Also, for 
weeks worked, annual earnings, and weekly earnings, must report positive # weeks and # hours worked. 
For now, include all races - white, Am. Indian, Asian. */
drop if classwkg==1
drop if school==2
/* To be comparable in all samples: note that 1940 weeks worked are different from 1950 on. Census asked 
about "full time" equivalent weeks (40 hours per week). So, if worked 20 hours for 50 weeks, would report 
26 weeks of 'full time' work. To be comparable, restrict to full-time workers - 40 weeks a year. Also, 
to cut out extreme low outliers, assume must make 1/2 of federal minimum wage, which would be:
$6/week (1940)
$8/week (1950)
$20/week (1960)
$32/week (1970)
in current dollars.
These restrictions explained in Margo (1995)*/
/* Drop if annual earnings below 1/2 federal minimum wage*/
drop if incwage<240
** WEEKS WORKED
gen wkless40=(wkswork1<40 & wkswork1!=.)
** ANNUAL EARNINGS
/* Adjust for inflation - 1999 dollars*/
gen incwage1=incwage*11.99
/* Replace topcoded incomes with incomeX1.4 according to Goldin and Margo (1992)*/
replace incwage1=incwage1*1.4 if incwage==5001
lab var incwage1 "incwage adjusted for infl. (1999=1.00)"
gen lnearn=ln(incwage1) if wkswork1>=40 
lab var lnearn "ln(annual earnings) if 40+ weeks"

/* TWO SETS OF SAMPLE WEIGHTS: TOTAL COUNT, AND ONLY THOSE THAT WORK MORE THAN 40 WEEKS*/
sort edcat expcat
drop temp*
gen temp=(black==1 & migsouth==0)
gen temp01=(black==0 & migsouth==0)
quietly by edcat expcat: egen countbnmi=sum(temp)
quietly by edcat expcat: egen countwnmi=sum(temp01)
label var countbnmi "# native blacks, meet sample, by group" 
label var countwnmi "# native whites, meet sample, by group" 
drop temp*
gen temp=(black==1 & migsouth==0 & wkless40==0)
gen temp01=(black==0 & migsouth==0 & wkless40==0)
quietly by edcat expcat: egen countbnmi01=sum(temp)
quietly by edcat expcat: egen countwnmi01=sum(temp01)
label var countbnmi01 "# native blacks, work 40+ weeks, by group" 
label var countwnmi01 "# native whites, work 40+ weeks, by group" 
drop temp*

/* Can add other subdivisions here*/
save 1940b01_educ.dta, replace

collapse lnearn wkless40 count* per* noreast-pacific, by(edcat expcat black migsouth)
save 1940b02_educ.dta, replace

/**
clear
use 1940b01_educ.dta
collapse lnearn wkless40 count* per* noreast-pacific, by(edcat expcat migsouth)
save 1940b03_educ.dta, replace

clear
use 1940b01_educ.dta
drop count*
sort edcat migsouth
gen ones=1
gen temp=(migsouth==0)
gen temp01=(migsouth==1)
by edcat migsouth: egen count=sum(ones)
by edcat migsouth: egen countnmi=sum(temp)
by edcat migsouth: egen countmi=sum(temp01)
collapse lnearn wkless40 count* per*, by(edcat migsouth)
save 1940b04_educ.dta, replace

use 1940b01_educ.dta
keep edcat expcat countbmi
sort edcat expcat
drop if expcat==expcat[_n-1]
list edcat expcat countbmi
**/
